@@ -1,5 +1,6 @@
 /*
  * Copyright 1994-2018 Brad Lanam, Walnut Creek, CA
+ * Copyright 2023 Brad Lanam, Pleasant Hill, CA
  */
 
 #include "config.h"
@@ -31,12 +32,7 @@
 #endif
 
 char *
-# if _proto_stdc
 strdup (const char *ptr)
-# else
-strdup (ptr)
-    const char        *ptr;
-# endif
 {
   Size_t        len;
   char          *nptr;
